@@ -11,7 +11,6 @@ __all__ = [
 from collections.abc import Buffer, Callable, Iterable, Sequence
 from contextlib import contextmanager, suppress
 from enum import Enum
-from functools import partial
 from os import PathLike
 from re import compile as re_compile, IGNORECASE
 from sqlite3 import connect, Connection, Cursor, ProgrammingError
@@ -19,6 +18,7 @@ from typing import Any, Final, Literal, Self
 
 
 CRE_SELECT_SQL_match: Final = re_compile(r"\s*SELECT\b", IGNORECASE).match
+CRE_COLNAME_sub: Final = re_compile(r" \[[^]]+\]$").sub
 
 
 class FetchType(Enum):
@@ -201,7 +201,7 @@ def query(
                 case FetchType.one:
                     cursor.row_factory = lambda _, record: record[0]
                 case FetchType.dict:
-                    fields = tuple(f[0] for f in cursor.description)
+                    fields = tuple(CRE_COLNAME_sub("", f[0]) for f in cursor.description)
                     cursor.row_factory = lambda _, record: dict(zip(fields, record))
     return cursor
 
@@ -248,7 +248,7 @@ def find(
             case FetchType.one:
                 return record[0]
             case FetchType.dict:
-                return dict(zip((f[0] for f in cursor.description), record))
+                return dict(zip((CRE_COLNAME_sub("", f[0]) for f in cursor.description), record))
             case _:
                 return record
 
